# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.scheduler_v1beta1.proto import cloudscheduler_pb2 as google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2
from google.cloud.scheduler_v1beta1.proto import job_pb2 as google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CloudSchedulerStub(object):
  """The Cloud Scheduler API allows external entities to reliably
  schedule asynchronous jobs.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListJobs = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/ListJobs',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.ListJobsRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.ListJobsResponse.FromString,
        )
    self.GetJob = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/GetJob',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.GetJobRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
    self.CreateJob = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/CreateJob',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.CreateJobRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
    self.UpdateJob = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/UpdateJob',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.UpdateJobRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
    self.DeleteJob = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/DeleteJob',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.DeleteJobRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.PauseJob = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/PauseJob',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.PauseJobRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
    self.ResumeJob = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/ResumeJob',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.ResumeJobRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.FromString,
        )
    self.RunJob = channel.unary_unary(
        '/google.cloud.scheduler.v1beta1.CloudScheduler/RunJob',
        request_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.RunJobRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.FromString,
        )


class CloudSchedulerServicer(object):
  """The Cloud Scheduler API allows external entities to reliably
  schedule asynchronous jobs.
  """

  def ListJobs(self, request, context):
    """Lists jobs.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetJob(self, request, context):
    """Gets a job.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateJob(self, request, context):
    """Creates a job.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateJob(self, request, context):
    """Updates a job.

    If successful, the updated [Job][google.cloud.scheduler.v1beta1.Job] is returned. If the job does
    not exist, `NOT_FOUND` is returned.

    If UpdateJob does not successfully return, it is possible for the
    job to be in an [Job.State.UPDATE_FAILED][google.cloud.scheduler.v1beta1.Job.State.UPDATE_FAILED] state. A job in this state may
    not be executed. If this happens, retry the UpdateJob request
    until a successful response is received.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteJob(self, request, context):
    """Deletes a job.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PauseJob(self, request, context):
    """Pauses a job.

    If a job is paused then the system will stop executing the job
    until it is re-enabled via [ResumeJob][google.cloud.scheduler.v1beta1.CloudScheduler.ResumeJob]. The
    state of the job is stored in [state][google.cloud.scheduler.v1beta1.Job.state]; if paused it
    will be set to [Job.State.PAUSED][google.cloud.scheduler.v1beta1.Job.State.PAUSED]. A job must be in [Job.State.ENABLED][google.cloud.scheduler.v1beta1.Job.State.ENABLED]
    to be paused.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResumeJob(self, request, context):
    """Resume a job.

    This method reenables a job after it has been [Job.State.PAUSED][google.cloud.scheduler.v1beta1.Job.State.PAUSED]. The
    state of a job is stored in [Job.state][google.cloud.scheduler.v1beta1.Job.state]; after calling this method it
    will be set to [Job.State.ENABLED][google.cloud.scheduler.v1beta1.Job.State.ENABLED]. A job must be in
    [Job.State.PAUSED][google.cloud.scheduler.v1beta1.Job.State.PAUSED] to be resumed.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RunJob(self, request, context):
    """Forces a job to run now.

    When this method is called, Cloud Scheduler will dispatch the job, even
    if the job is already running.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CloudSchedulerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListJobs': grpc.unary_unary_rpc_method_handler(
          servicer.ListJobs,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.ListJobsRequest.FromString,
          response_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.ListJobsResponse.SerializeToString,
      ),
      'GetJob': grpc.unary_unary_rpc_method_handler(
          servicer.GetJob,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.GetJobRequest.FromString,
          response_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
      ),
      'CreateJob': grpc.unary_unary_rpc_method_handler(
          servicer.CreateJob,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.CreateJobRequest.FromString,
          response_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
      ),
      'UpdateJob': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateJob,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.UpdateJobRequest.FromString,
          response_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
      ),
      'DeleteJob': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteJob,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.DeleteJobRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'PauseJob': grpc.unary_unary_rpc_method_handler(
          servicer.PauseJob,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.PauseJobRequest.FromString,
          response_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
      ),
      'ResumeJob': grpc.unary_unary_rpc_method_handler(
          servicer.ResumeJob,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.ResumeJobRequest.FromString,
          response_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
      ),
      'RunJob': grpc.unary_unary_rpc_method_handler(
          servicer.RunJob,
          request_deserializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_cloudscheduler__pb2.RunJobRequest.FromString,
          response_serializer=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.Job.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.cloud.scheduler.v1beta1.CloudScheduler', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/scheduler_v1beta1/proto/cloudscheduler.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.scheduler_v1beta1.proto import job_pb2 as google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/cloud/scheduler_v1beta1/proto/cloudscheduler.proto',
  package='google.cloud.scheduler.v1beta1',
  syntax='proto3',
  serialized_pb=_b('\n9google/cloud/scheduler_v1beta1/proto/cloudscheduler.proto\x12\x1egoogle.cloud.scheduler.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a.google/cloud/scheduler_v1beta1/proto/job.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\"H\n\x0fListJobsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t\"^\n\x10ListJobsResponse\x12\x31\n\x04jobs\x18\x01 \x03(\x0b\x32#.google.cloud.scheduler.v1beta1.Job\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1d\n\rGetJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"T\n\x10\x43reateJobRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x30\n\x03job\x18\x02 \x01(\x0b\x32#.google.cloud.scheduler.v1beta1.Job\"u\n\x10UpdateJobRequest\x12\x30\n\x03job\x18\x01 \x01(\x0b\x32#.google.cloud.scheduler.v1beta1.Job\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x10\x44\x65leteJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1f\n\x0fPauseJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10ResumeJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\rRunJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t2\x88\n\n\x0e\x43loudScheduler\x12\xa4\x01\n\x08ListJobs\x12/.google.cloud.scheduler.v1beta1.ListJobsRequest\x1a\x30.google.cloud.scheduler.v1beta1.ListJobsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/v1beta1/{parent=projects/*/locations/*}/jobs\x12\x93\x01\n\x06GetJob\x12-.google.cloud.scheduler.v1beta1.GetJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job\"5\x82\xd3\xe4\x93\x02/\x12-/v1beta1/{name=projects/*/locations/*/jobs/*}\x12\x9e\x01\n\tCreateJob\x12\x30.google.cloud.scheduler.v1beta1.CreateJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job\":\x82\xd3\xe4\x93\x02\x34\"-/v1beta1/{parent=projects/*/locations/*}/jobs:\x03job\x12\xa2\x01\n\tUpdateJob\x12\x30.google.cloud.scheduler.v1beta1.UpdateJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job\">\x82\xd3\xe4\x93\x02\x38\x32\x31/v1beta1/{job.name=projects/*/locations/*/jobs/*}:\x03job\x12\x8c\x01\n\tDeleteJob\x12\x30.google.cloud.scheduler.v1beta1.DeleteJobRequest\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/*-/v1beta1/{name=projects/*/locations/*/jobs/*}\x12\xa0\x01\n\x08PauseJob\x12/.google.cloud.scheduler.v1beta1.PauseJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job\">\x82\xd3\xe4\x93\x02\x38\"3/v1beta1/{name=projects/*/locations/*/jobs/*}:pause:\x01*\x12\xa3\x01\n\tResumeJob\x12\x30.google.cloud.scheduler.v1beta1.ResumeJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job\"?\x82\xd3\xe4\x93\x02\x39\"4/v1beta1/{name=projects/*/locations/*/jobs/*}:resume:\x01*\x12\x9a\x01\n\x06RunJob\x12-.google.cloud.scheduler.v1beta1.RunJobRequest\x1a#.google.cloud.scheduler.v1beta1.Job\"<\x82\xd3\xe4\x93\x02\x36\"1/v1beta1/{name=projects/*/locations/*/jobs/*}:run:\x01*B\x7f\n\"com.google.cloud.scheduler.v1beta1B\x0eSchedulerProtoP\x01ZGgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1beta1;schedulerb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_LISTJOBSREQUEST = _descriptor.Descriptor(
  name='ListJobsRequest',
  full_name='google.cloud.scheduler.v1beta1.ListJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.cloud.scheduler.v1beta1.ListJobsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.cloud.scheduler.v1beta1.ListJobsRequest.page_size', index=1,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.cloud.scheduler.v1beta1.ListJobsRequest.page_token', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=306,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
  name='ListJobsResponse',
  full_name='google.cloud.scheduler.v1beta1.ListJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobs', full_name='google.cloud.scheduler.v1beta1.ListJobsResponse.jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.cloud.scheduler.v1beta1.ListJobsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=402,
)


_GETJOBREQUEST = _descriptor.Descriptor(
  name='GetJobRequest',
  full_name='google.cloud.scheduler.v1beta1.GetJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.scheduler.v1beta1.GetJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=433,
)


_CREATEJOBREQUEST = _descriptor.Descriptor(
  name='CreateJobRequest',
  full_name='google.cloud.scheduler.v1beta1.CreateJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.cloud.scheduler.v1beta1.CreateJobRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='google.cloud.scheduler.v1beta1.CreateJobRequest.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=519,
)


_UPDATEJOBREQUEST = _descriptor.Descriptor(
  name='UpdateJobRequest',
  full_name='google.cloud.scheduler.v1beta1.UpdateJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='google.cloud.scheduler.v1beta1.UpdateJobRequest.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.cloud.scheduler.v1beta1.UpdateJobRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=638,
)


_DELETEJOBREQUEST = _descriptor.Descriptor(
  name='DeleteJobRequest',
  full_name='google.cloud.scheduler.v1beta1.DeleteJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.scheduler.v1beta1.DeleteJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=672,
)


_PAUSEJOBREQUEST = _descriptor.Descriptor(
  name='PauseJobRequest',
  full_name='google.cloud.scheduler.v1beta1.PauseJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.scheduler.v1beta1.PauseJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=705,
)


_RESUMEJOBREQUEST = _descriptor.Descriptor(
  name='ResumeJobRequest',
  full_name='google.cloud.scheduler.v1beta1.ResumeJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.scheduler.v1beta1.ResumeJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=707,
  serialized_end=739,
)


_RUNJOBREQUEST = _descriptor.Descriptor(
  name='RunJobRequest',
  full_name='google.cloud.scheduler.v1beta1.RunJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.scheduler.v1beta1.RunJobRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=770,
)

_LISTJOBSRESPONSE.fields_by_name['jobs'].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB
_CREATEJOBREQUEST.fields_by_name['job'].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name['job'].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name['ListJobsRequest'] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name['ListJobsResponse'] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name['GetJobRequest'] = _GETJOBREQUEST
DESCRIPTOR.message_types_by_name['CreateJobRequest'] = _CREATEJOBREQUEST
DESCRIPTOR.message_types_by_name['UpdateJobRequest'] = _UPDATEJOBREQUEST
DESCRIPTOR.message_types_by_name['DeleteJobRequest'] = _DELETEJOBREQUEST
DESCRIPTOR.message_types_by_name['PauseJobRequest'] = _PAUSEJOBREQUEST
DESCRIPTOR.message_types_by_name['ResumeJobRequest'] = _RESUMEJOBREQUEST
DESCRIPTOR.message_types_by_name['RunJobRequest'] = _RUNJOBREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTJOBSREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for listing jobs using
  [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
  
  
  Attributes:
      parent:
          Required.  The location name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID``.
      page_size:
          Requested page size.  The maximum page size is 500. If
          unspecified, the page size will be the maximum. Fewer jobs
          than requested might be returned, even if more jobs exist; use
          next\_page\_token to determine if more jobs exist.
      page_token:
          A token identifying a page of results the server will return.
          To request the first page results, page\_token must be empty.
          To request the next page of results, page\_token must be the
          value of [next\_page\_token][google.cloud.scheduler.v1beta1.Li
          stJobsResponse.next\_page\_token] returned from the previous
          call to [ListJobs][google.cloud.scheduler.v1beta1.CloudSchedul
          er.ListJobs]. It is an error to switch the value of [filter][g
          oogle.cloud.scheduler.v1beta1.ListJobsRequest.filter] or [orde
          r\_by][google.cloud.scheduler.v1beta1.ListJobsRequest.order\_b
          y] while iterating through pages.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.ListJobsRequest)
  ))
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTJOBSRESPONSE,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Response message for listing jobs using
  [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
  
  
  Attributes:
      jobs:
          The list of jobs.
      next_page_token:
          A token to retrieve next page of results. Pass this value in
          the [page\_token][google.cloud.scheduler.v1beta1.ListJobsReque
          st.page\_token] field in the subsequent call to [ListJobs][goo
          gle.cloud.scheduler.v1beta1.CloudScheduler.ListJobs] to
          retrieve the next page of results. If this is empty it
          indicates that there are no more results through which to
          paginate.  The page token is valid for only 2 hours.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.ListJobsResponse)
  ))
_sym_db.RegisterMessage(ListJobsResponse)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for
  [GetJob][google.cloud.scheduler.v1beta1.CloudScheduler.GetJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.GetJobRequest)
  ))
_sym_db.RegisterMessage(GetJobRequest)

CreateJobRequest = _reflection.GeneratedProtocolMessageType('CreateJobRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEJOBREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for
  [CreateJob][google.cloud.scheduler.v1beta1.CloudScheduler.CreateJob].
  
  
  Attributes:
      parent:
          Required.  The location name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID``.
      job:
          Required.  The job to add. The user can optionally specify a
          name for the job in
          [name][google.cloud.scheduler.v1beta1.Job.name].
          [name][google.cloud.scheduler.v1beta1.Job.name] cannot be the
          same as an existing job. If a name is not specified then the
          system will generate a random unique name that will be
          returned ([name][google.cloud.scheduler.v1beta1.Job.name]) in
          the response.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.CreateJobRequest)
  ))
_sym_db.RegisterMessage(CreateJobRequest)

UpdateJobRequest = _reflection.GeneratedProtocolMessageType('UpdateJobRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEJOBREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for
  [UpdateJob][google.cloud.scheduler.v1beta1.CloudScheduler.UpdateJob].
  
  
  Attributes:
      job:
          Required.  The new job properties.
          [name][google.cloud.scheduler.v1beta1.Job.name] must be
          specified.  Output only fields cannot be modified using
          UpdateJob. Any value specified for an output only field will
          be ignored.
      update_mask:
          A mask used to specify which fields of the job are being
          updated.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.UpdateJobRequest)
  ))
_sym_db.RegisterMessage(UpdateJobRequest)

DeleteJobRequest = _reflection.GeneratedProtocolMessageType('DeleteJobRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEJOBREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for deleting a job using
  [DeleteJob][google.cloud.scheduler.v1beta1.CloudScheduler.DeleteJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.DeleteJobRequest)
  ))
_sym_db.RegisterMessage(DeleteJobRequest)

PauseJobRequest = _reflection.GeneratedProtocolMessageType('PauseJobRequest', (_message.Message,), dict(
  DESCRIPTOR = _PAUSEJOBREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for
  [PauseJob][google.cloud.scheduler.v1beta1.CloudScheduler.PauseJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.PauseJobRequest)
  ))
_sym_db.RegisterMessage(PauseJobRequest)

ResumeJobRequest = _reflection.GeneratedProtocolMessageType('ResumeJobRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESUMEJOBREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for
  [ResumeJob][google.cloud.scheduler.v1beta1.CloudScheduler.ResumeJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.ResumeJobRequest)
  ))
_sym_db.RegisterMessage(ResumeJobRequest)

RunJobRequest = _reflection.GeneratedProtocolMessageType('RunJobRequest', (_message.Message,), dict(
  DESCRIPTOR = _RUNJOBREQUEST,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.cloudscheduler_pb2'
  ,
  __doc__ = """Request message for forcing a job to run now using
  [RunJob][google.cloud.scheduler.v1beta1.CloudScheduler.RunJob].
  
  
  Attributes:
      name:
          Required.  The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.RunJobRequest)
  ))
_sym_db.RegisterMessage(RunJobRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.cloud.scheduler.v1beta1B\016SchedulerProtoP\001ZGgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1beta1;scheduler'))

_CLOUDSCHEDULER = _descriptor.ServiceDescriptor(
  name='CloudScheduler',
  full_name='google.cloud.scheduler.v1beta1.CloudScheduler',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=773,
  serialized_end=2061,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListJobs',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs',
    index=0,
    containing_service=None,
    input_type=_LISTJOBSREQUEST,
    output_type=_LISTJOBSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002/\022-/v1beta1/{parent=projects/*/locations/*}/jobs')),
  ),
  _descriptor.MethodDescriptor(
    name='GetJob',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.GetJob',
    index=1,
    containing_service=None,
    input_type=_GETJOBREQUEST,
    output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002/\022-/v1beta1/{name=projects/*/locations/*/jobs/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='CreateJob',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.CreateJob',
    index=2,
    containing_service=None,
    input_type=_CREATEJOBREQUEST,
    output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0024\"-/v1beta1/{parent=projects/*/locations/*}/jobs:\003job')),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateJob',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.UpdateJob',
    index=3,
    containing_service=None,
    input_type=_UPDATEJOBREQUEST,
    output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002821/v1beta1/{job.name=projects/*/locations/*/jobs/*}:\003job')),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteJob',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.DeleteJob',
    index=4,
    containing_service=None,
    input_type=_DELETEJOBREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002/*-/v1beta1/{name=projects/*/locations/*/jobs/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='PauseJob',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.PauseJob',
    index=5,
    containing_service=None,
    input_type=_PAUSEJOBREQUEST,
    output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0028\"3/v1beta1/{name=projects/*/locations/*/jobs/*}:pause:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='ResumeJob',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.ResumeJob',
    index=6,
    containing_service=None,
    input_type=_RESUMEJOBREQUEST,
    output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0029\"4/v1beta1/{name=projects/*/locations/*/jobs/*}:resume:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='RunJob',
    full_name='google.cloud.scheduler.v1beta1.CloudScheduler.RunJob',
    index=7,
    containing_service=None,
    input_type=_RUNJOBREQUEST,
    output_type=google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_job__pb2._JOB,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0026\"1/v1beta1/{name=projects/*/locations/*/jobs/*}:run:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CLOUDSCHEDULER)

DESCRIPTOR.services_by_name['CloudScheduler'] = _CLOUDSCHEDULER

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/scheduler_v1beta1/proto/job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.scheduler_v1beta1.proto import target_pb2 as google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_target__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/cloud/scheduler_v1beta1/proto/job.proto',
  package='google.cloud.scheduler.v1beta1',
  syntax='proto3',
  serialized_pb=_b('\n.google/cloud/scheduler_v1beta1/proto/job.proto\x12\x1egoogle.cloud.scheduler.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x31google/cloud/scheduler_v1beta1/proto/target.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\xd3\x05\n\x03Job\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x45\n\rpubsub_target\x18\x04 \x01(\x0b\x32,.google.cloud.scheduler.v1beta1.PubsubTargetH\x00\x12U\n\x16\x61pp_engine_http_target\x18\x05 \x01(\x0b\x32\x33.google.cloud.scheduler.v1beta1.AppEngineHttpTargetH\x00\x12\x41\n\x0bhttp_target\x18\x06 \x01(\x0b\x32*.google.cloud.scheduler.v1beta1.HttpTargetH\x00\x12\x10\n\x08schedule\x18\x14 \x01(\t\x12\x11\n\ttime_zone\x18\x15 \x01(\t\x12\x34\n\x10user_update_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x05state\x18\n \x01(\x0e\x32).google.cloud.scheduler.v1beta1.Job.State\x12\"\n\x06status\x18\x0b \x01(\x0b\x32\x12.google.rpc.Status\x12\x31\n\rschedule_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11last_attempt_time\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x0cretry_config\x18\x13 \x01(\x0b\x32+.google.cloud.scheduler.v1beta1.RetryConfig\"X\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x03\x12\x11\n\rUPDATE_FAILED\x10\x04\x42\x08\n\x06target\"\xe2\x01\n\x0bRetryConfig\x12\x13\n\x0bretry_count\x18\x01 \x01(\x05\x12\x35\n\x12max_retry_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\x14min_backoff_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\x14max_backoff_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x15\n\rmax_doublings\x18\x05 \x01(\x05\x42y\n\"com.google.cloud.scheduler.v1beta1B\x08JobProtoP\x01ZGgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1beta1;schedulerb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_target__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])



_JOB_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='google.cloud.scheduler.v1beta1.Job.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_FAILED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=879,
  serialized_end=967,
)
_sym_db.RegisterEnumDescriptor(_JOB_STATE)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='google.cloud.scheduler.v1beta1.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.scheduler.v1beta1.Job.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.cloud.scheduler.v1beta1.Job.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pubsub_target', full_name='google.cloud.scheduler.v1beta1.Job.pubsub_target', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_engine_http_target', full_name='google.cloud.scheduler.v1beta1.Job.app_engine_http_target', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_target', full_name='google.cloud.scheduler.v1beta1.Job.http_target', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='google.cloud.scheduler.v1beta1.Job.schedule', index=5,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='google.cloud.scheduler.v1beta1.Job.time_zone', index=6,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_update_time', full_name='google.cloud.scheduler.v1beta1.Job.user_update_time', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='google.cloud.scheduler.v1beta1.Job.state', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.cloud.scheduler.v1beta1.Job.status', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedule_time', full_name='google.cloud.scheduler.v1beta1.Job.schedule_time', index=10,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_attempt_time', full_name='google.cloud.scheduler.v1beta1.Job.last_attempt_time', index=11,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retry_config', full_name='google.cloud.scheduler.v1beta1.Job.retry_config', index=12,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JOB_STATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='google.cloud.scheduler.v1beta1.Job.target',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=254,
  serialized_end=977,
)


_RETRYCONFIG = _descriptor.Descriptor(
  name='RetryConfig',
  full_name='google.cloud.scheduler.v1beta1.RetryConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='retry_count', full_name='google.cloud.scheduler.v1beta1.RetryConfig.retry_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_retry_duration', full_name='google.cloud.scheduler.v1beta1.RetryConfig.max_retry_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_backoff_duration', full_name='google.cloud.scheduler.v1beta1.RetryConfig.min_backoff_duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_backoff_duration', full_name='google.cloud.scheduler.v1beta1.RetryConfig.max_backoff_duration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_doublings', full_name='google.cloud.scheduler.v1beta1.RetryConfig.max_doublings', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=980,
  serialized_end=1206,
)

_JOB.fields_by_name['pubsub_target'].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_target__pb2._PUBSUBTARGET
_JOB.fields_by_name['app_engine_http_target'].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_target__pb2._APPENGINEHTTPTARGET
_JOB.fields_by_name['http_target'].message_type = google_dot_cloud_dot_scheduler__v1beta1_dot_proto_dot_target__pb2._HTTPTARGET
_JOB.fields_by_name['user_update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name['state'].enum_type = _JOB_STATE
_JOB.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_JOB.fields_by_name['schedule_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name['last_attempt_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOB.fields_by_name['retry_config'].message_type = _RETRYCONFIG
_JOB_STATE.containing_type = _JOB
_JOB.oneofs_by_name['target'].fields.append(
  _JOB.fields_by_name['pubsub_target'])
_JOB.fields_by_name['pubsub_target'].containing_oneof = _JOB.oneofs_by_name['target']
_JOB.oneofs_by_name['target'].fields.append(
  _JOB.fields_by_name['app_engine_http_target'])
_JOB.fields_by_name['app_engine_http_target'].containing_oneof = _JOB.oneofs_by_name['target']
_JOB.oneofs_by_name['target'].fields.append(
  _JOB.fields_by_name['http_target'])
_JOB.fields_by_name['http_target'].containing_oneof = _JOB.oneofs_by_name['target']
_RETRYCONFIG.fields_by_name['max_retry_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYCONFIG.fields_by_name['min_backoff_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYCONFIG.fields_by_name['max_backoff_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['RetryConfig'] = _RETRYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), dict(
  DESCRIPTOR = _JOB,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.job_pb2'
  ,
  __doc__ = """Configuration for a job. The maximum allowed size for a job is 100KB.
  
  
  Attributes:
      name:
          The job name. For example:
          ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.  -
          ``PROJECT_ID`` can contain letters ([A-Za-z]), numbers
          ([0-9]),    hyphens (-), colons (:), or periods (.). For more
          information, see    `Identifying    projects
          <https://cloud.google.com/resource-manager/docs/creating-
          managing-projects#identifying_projects>`__ -  ``LOCATION_ID``
          is the canonical ID for the job's location. The list    of
          available locations can be obtained by calling    [ListLocatio
          ns][google.cloud.location.Locations.ListLocations]. For
          more information, see
          https://cloud.google.com/about/locations/. -  ``JOB_ID`` can
          contain only letters ([A-Za-z]), numbers ([0-9]),    hyphens
          (-), or underscores (\_). The maximum length is 500
          characters.
      description:
          A human-readable description for the job. This string must not
          contain more than 500 characters.
      target:
          Required.  Delivery settings containing destination and
          parameters.
      pubsub_target:
          Pub/Sub target.
      app_engine_http_target:
          App Engine HTTP target.
      http_target:
          HTTP target.
      schedule:
          Required.  Describes the schedule on which the job will be
          executed.  As a general rule, execution ``n + 1`` of a job
          will not begin until execution ``n`` has finished. Cloud
          Scheduler will never allow two simultaneously outstanding
          executions. For example, this implies that if the ``n+1``\ th
          execution is scheduled to run at 16:00 but the ``n``\ th
          execution takes until 16:15, the ``n+1``\ th execution will
          not start until ``16:15``. A scheduled start time will be
          delayed if the previous execution has not ended when its
          scheduled time occurs.  If [retry\_count][google.cloud.schedul
          er.v1beta1.RetryConfig.retry\_count] > 0 and a job attempt
          fails, the job will be tried a total of [retry\_count][google.
          cloud.scheduler.v1beta1.RetryConfig.retry\_count] times, with
          exponential backoff, until the next scheduled start time.  The
          schedule can be either of the following types:  -  `Crontab
          <http://en.wikipedia.org/wiki/Cron#Overview>`__ -  English-
          like    `schedule
          <https://cloud.google.com/scheduler/docs/configuring/cron-job-
          schedules>`__
      time_zone:
          Specifies the time zone to be used in interpreting
          [schedule][google.cloud.scheduler.v1beta1.Job.schedule]. The
          value of this field must be a time zone name from the `tz
          database <http://en.wikipedia.org/wiki/Tz_database>`__.  Note
          that some time zones include a provision for daylight savings
          time. The rules for daylight saving time are determined by the
          chosen tz. For UTC use the string "utc". If a time zone is not
          specified, the default will be in UTC (also known as GMT).
      user_update_time:
          Output only. The creation time of the job.
      state:
          Output only. State of the job.
      status:
          Output only. The response from the target for the last
          attempted execution.
      schedule_time:
          Output only. The next time the job is scheduled. Note that
          this may be a retry of a previously failed attempt or the next
          execution time according to the schedule.
      last_attempt_time:
          Output only. The time the last job attempt started.
      retry_config:
          Settings that determine the retry behavior.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.Job)
  ))
_sym_db.RegisterMessage(Job)

RetryConfig = _reflection.GeneratedProtocolMessageType('RetryConfig', (_message.Message,), dict(
  DESCRIPTOR = _RETRYCONFIG,
  __module__ = 'google.cloud.scheduler_v1beta1.proto.job_pb2'
  ,
  __doc__ = """Settings that determine the retry behavior.
  
  By default, if a job does not complete successfully (meaning that an
  acknowledgement is not received from the handler, then it will be
  retried with exponential backoff according to the settings in
  [RetryConfig][google.cloud.scheduler.v1beta1.RetryConfig].
  
  
  Attributes:
      retry_count:
          The number of attempts that the system will make to run a job
          using the exponential backoff procedure described by [max\_dou
          blings][google.cloud.scheduler.v1beta1.RetryConfig.max\_doubli
          ngs].  The default value of retry\_count is zero.  If
          retry\_count is zero, a job attempt will *not* be retried if
          it fails. Instead the Cloud Scheduler system will wait for the
          next scheduled execution time.  If retry\_count is set to a
          non-zero number then Cloud Scheduler will retry failed
          attempts, using exponential backoff, retry\_count times, or
          until the next scheduled execution time, whichever comes
          first.  Values greater than 5 and negative values are not
          allowed.
      max_retry_duration:
          The time limit for retrying a failed job, measured from time
          when an execution was first attempted. If specified with [retr
          y\_count][google.cloud.scheduler.v1beta1.RetryConfig.retry\_co
          unt], the job will be retried until both limits are reached.
          The default value for max\_retry\_duration is zero, which
          means retry duration is unlimited.
      min_backoff_duration:
          The minimum amount of time to wait before retrying a job after
          it fails.  The default value of this field is 5 seconds.
      max_backoff_duration:
          The maximum amount of time to wait before retrying a job after
          it fails.  The default value of this field is 1 hour.
      max_doublings:
          The time between retries will double ``max_doublings`` times.
          A job's retry interval starts at [min\_backoff\_duration][goog
          le.cloud.scheduler.v1beta1.RetryConfig.min\_backoff\_duration]
          , then doubles ``max_doublings`` times, then increases
          linearly, and finally retries retries at intervals of [max\_ba
          ckoff\_duration][google.cloud.scheduler.v1beta1.RetryConfig.ma
          x\_backoff\_duration] up to [retry\_count][google.cloud.schedu
          ler.v1beta1.RetryConfig.retry\_count] times.  For example, if 
          [min\_backoff\_duration][google.cloud.scheduler.v1beta1.RetryC
          onfig.min\_backoff\_duration] is 10s, [max\_backoff\_duration]
          [google.cloud.scheduler.v1beta1.RetryConfig.max\_backoff\_dura
          tion] is 300s, and ``max_doublings`` is 3, then the a job will
          first be retried in 10s. The retry interval will double three
          times, and then increase linearly by 2^3 \* 10s. Finally, the
          job will retry at intervals of [max\_backoff\_duration][google
          .cloud.scheduler.v1beta1.RetryConfig.max\_backoff\_duration]
          until the job has been attempted [retry\_count][google.cloud.s
          cheduler.v1beta1.RetryConfig.retry\_count] times. Thus, the
          requests will retry at 10s, 20s, 40s, 80s, 160s, 240s, 300s,
          300s, ....  The default value of this field is 5.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.scheduler.v1beta1.RetryConfig)
  ))
_sym_db.RegisterMessage(RetryConfig)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.cloud.scheduler.v1beta1B\010JobProtoP\001ZGgoogle.golang.org/genproto/googleapis/cloud/scheduler/v1beta1;scheduler'))
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Accesses the google.cloud.scheduler.v1beta1 CloudScheduler API."""

import functools
import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.grpc_helpers
import google.api_core.page_iterator
import google.api_core.path_template
import grpc

from google.cloud.scheduler_v1beta1.gapic import cloud_scheduler_client_config
from google.cloud.scheduler_v1beta1.gapic import enums
from google.cloud.scheduler_v1beta1.gapic.transports import cloud_scheduler_grpc_transport
from google.cloud.scheduler_v1beta1.proto import cloudscheduler_pb2
from google.cloud.scheduler_v1beta1.proto import cloudscheduler_pb2_grpc
from google.cloud.scheduler_v1beta1.proto import job_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2

_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
    'google-cloud-scheduler', ).version


class CloudSchedulerClient(object):
    """
    The Cloud Scheduler API allows external entities to reliably
    schedule asynchronous jobs.
    """

    SERVICE_ADDRESS = 'cloudscheduler.googleapis.com:443'
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = 'google.cloud.scheduler.v1beta1.CloudScheduler'

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            CloudSchedulerClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(
            filename)
        kwargs['credentials'] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @classmethod
    def project_path(cls, project):
        """Return a fully-qualified project string."""
        return google.api_core.path_template.expand(
            'projects/{project}',
            project=project,
        )

    @classmethod
    def location_path(cls, project, location):
        """Return a fully-qualified location string."""
        return google.api_core.path_template.expand(
            'projects/{project}/locations/{location}',
            project=project,
            location=location,
        )

    @classmethod
    def job_path(cls, project, location, job):
        """Return a fully-qualified job string."""
        return google.api_core.path_template.expand(
            'projects/{project}/locations/{location}/jobs/{job}',
            project=project,
            location=location,
            job=job,
        )

    def __init__(self,
                 transport=None,
                 channel=None,
                 credentials=None,
                 client_config=cloud_scheduler_client_config.config,
                 client_info=None):
        """Constructor.

        Args:
            transport (Union[~.CloudSchedulerGrpcTransport,
                    Callable[[~.Credentials, type], ~.CloudSchedulerGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config:
            warnings.warn('The `client_config` argument is deprecated.',
                          PendingDeprecationWarning)
        if channel:
            warnings.warn(
                'The `channel` argument is deprecated; use '
                '`transport` instead.', PendingDeprecationWarning)

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=cloud_scheduler_grpc_transport.
                    CloudSchedulerGrpcTransport,
                )
            else:
                if credentials:
                    raise ValueError(
                        'Received both a transport instance and '
                        'credentials; these are mutually exclusive.')
                self.transport = transport
        else:
            self.transport = cloud_scheduler_grpc_transport.CloudSchedulerGrpcTransport(
                address=self.SERVICE_ADDRESS,
                channel=channel,
                credentials=credentials,
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION, )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config['interfaces'][self._INTERFACE_NAME], )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def list_jobs(self,
                  parent,
                  page_size=None,
                  retry=google.api_core.gapic_v1.method.DEFAULT,
                  timeout=google.api_core.gapic_v1.method.DEFAULT,
                  metadata=None):
        """
        Lists jobs.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> parent = client.location_path('[PROJECT]', '[LOCATION]')
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_jobs(parent):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_jobs(parent).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): Required.

                The location name. For example:
                ``projects/PROJECT_ID/locations/LOCATION_ID``.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.gax.PageIterator` instance. By default, this
            is an iterable of :class:`~google.cloud.scheduler_v1beta1.types.Job` instances.
            This object can also be configured to iterate over the pages
            of the response through the `options` parameter.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'list_jobs' not in self._inner_api_calls:
            self._inner_api_calls[
                'list_jobs'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.list_jobs,
                    default_retry=self._method_configs['ListJobs'].retry,
                    default_timeout=self._method_configs['ListJobs'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.ListJobsRequest(
            parent=parent,
            page_size=page_size,
        )
        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls['list_jobs'],
                retry=retry,
                timeout=timeout,
                metadata=metadata),
            request=request,
            items_field='jobs',
            request_token_field='page_token',
            response_token_field='next_page_token',
        )
        return iterator

    def get_job(self,
                name,
                retry=google.api_core.gapic_v1.method.DEFAULT,
                timeout=google.api_core.gapic_v1.method.DEFAULT,
                metadata=None):
        """
        Gets a job.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')
            >>>
            >>> response = client.get_job(name)

        Args:
            name (str): Required.

                The job name. For example:
                ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.scheduler_v1beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'get_job' not in self._inner_api_calls:
            self._inner_api_calls[
                'get_job'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.get_job,
                    default_retry=self._method_configs['GetJob'].retry,
                    default_timeout=self._method_configs['GetJob'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.GetJobRequest(name=name, )
        return self._inner_api_calls['get_job'](
            request, retry=retry, timeout=timeout, metadata=metadata)

    def create_job(self,
                   parent,
                   job,
                   retry=google.api_core.gapic_v1.method.DEFAULT,
                   timeout=google.api_core.gapic_v1.method.DEFAULT,
                   metadata=None):
        """
        Creates a job.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> parent = client.location_path('[PROJECT]', '[LOCATION]')
            >>>
            >>> # TODO: Initialize `job`:
            >>> job = {}
            >>>
            >>> response = client.create_job(parent, job)

        Args:
            parent (str): Required.

                The location name. For example:
                ``projects/PROJECT_ID/locations/LOCATION_ID``.
            job (Union[dict, ~google.cloud.scheduler_v1beta1.types.Job]): Required.

                The job to add. The user can optionally specify a name for the job in
                ``name``. ``name`` cannot be the same as an existing job. If a name is
                not specified then the system will generate a random unique name that
                will be returned (``name``) in the response.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.scheduler_v1beta1.types.Job`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.scheduler_v1beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'create_job' not in self._inner_api_calls:
            self._inner_api_calls[
                'create_job'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.create_job,
                    default_retry=self._method_configs['CreateJob'].retry,
                    default_timeout=self._method_configs['CreateJob'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.CreateJobRequest(
            parent=parent,
            job=job,
        )
        return self._inner_api_calls['create_job'](
            request, retry=retry, timeout=timeout, metadata=metadata)

    def update_job(self,
                   job,
                   update_mask=None,
                   retry=google.api_core.gapic_v1.method.DEFAULT,
                   timeout=google.api_core.gapic_v1.method.DEFAULT,
                   metadata=None):
        """
        Updates a job.

        If successful, the updated ``Job`` is returned. If the job does not
        exist, ``NOT_FOUND`` is returned.

        If UpdateJob does not successfully return, it is possible for the job to
        be in an ``Job.State.UPDATE_FAILED`` state. A job in this state may not
        be executed. If this happens, retry the UpdateJob request until a
        successful response is received.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> # TODO: Initialize `job`:
            >>> job = {}
            >>>
            >>> response = client.update_job(job)

        Args:
            job (Union[dict, ~google.cloud.scheduler_v1beta1.types.Job]): Required.

                The new job properties. ``name`` must be specified.

                Output only fields cannot be modified using UpdateJob. Any value
                specified for an output only field will be ignored.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.scheduler_v1beta1.types.Job`
            update_mask (Union[dict, ~google.cloud.scheduler_v1beta1.types.FieldMask]): A  mask used to specify which fields of the job are being updated.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.scheduler_v1beta1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.scheduler_v1beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'update_job' not in self._inner_api_calls:
            self._inner_api_calls[
                'update_job'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.update_job,
                    default_retry=self._method_configs['UpdateJob'].retry,
                    default_timeout=self._method_configs['UpdateJob'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.UpdateJobRequest(
            job=job,
            update_mask=update_mask,
        )
        return self._inner_api_calls['update_job'](
            request, retry=retry, timeout=timeout, metadata=metadata)

    def delete_job(self,
                   name,
                   retry=google.api_core.gapic_v1.method.DEFAULT,
                   timeout=google.api_core.gapic_v1.method.DEFAULT,
                   metadata=None):
        """
        Deletes a job.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')
            >>>
            >>> client.delete_job(name)

        Args:
            name (str): Required.

                The job name. For example:
                ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'delete_job' not in self._inner_api_calls:
            self._inner_api_calls[
                'delete_job'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.delete_job,
                    default_retry=self._method_configs['DeleteJob'].retry,
                    default_timeout=self._method_configs['DeleteJob'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.DeleteJobRequest(name=name, )
        self._inner_api_calls['delete_job'](
            request, retry=retry, timeout=timeout, metadata=metadata)

    def pause_job(self,
                  name,
                  retry=google.api_core.gapic_v1.method.DEFAULT,
                  timeout=google.api_core.gapic_v1.method.DEFAULT,
                  metadata=None):
        """
        Pauses a job.

        If a job is paused then the system will stop executing the job until it
        is re-enabled via ``ResumeJob``. The state of the job is stored in
        ``state``; if paused it will be set to ``Job.State.PAUSED``. A job must
        be in ``Job.State.ENABLED`` to be paused.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')
            >>>
            >>> response = client.pause_job(name)

        Args:
            name (str): Required.

                The job name. For example:
                ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.scheduler_v1beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'pause_job' not in self._inner_api_calls:
            self._inner_api_calls[
                'pause_job'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.pause_job,
                    default_retry=self._method_configs['PauseJob'].retry,
                    default_timeout=self._method_configs['PauseJob'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.PauseJobRequest(name=name, )
        return self._inner_api_calls['pause_job'](
            request, retry=retry, timeout=timeout, metadata=metadata)

    def resume_job(self,
                   name,
                   retry=google.api_core.gapic_v1.method.DEFAULT,
                   timeout=google.api_core.gapic_v1.method.DEFAULT,
                   metadata=None):
        """
        Resume a job.

        This method reenables a job after it has been ``Job.State.PAUSED``. The
        state of a job is stored in ``Job.state``; after calling this method it
        will be set to ``Job.State.ENABLED``. A job must be in
        ``Job.State.PAUSED`` to be resumed.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')
            >>>
            >>> response = client.resume_job(name)

        Args:
            name (str): Required.

                The job name. For example:
                ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.scheduler_v1beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'resume_job' not in self._inner_api_calls:
            self._inner_api_calls[
                'resume_job'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.resume_job,
                    default_retry=self._method_configs['ResumeJob'].retry,
                    default_timeout=self._method_configs['ResumeJob'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.ResumeJobRequest(name=name, )
        return self._inner_api_calls['resume_job'](
            request, retry=retry, timeout=timeout, metadata=metadata)

    def run_job(self,
                name,
                retry=google.api_core.gapic_v1.method.DEFAULT,
                timeout=google.api_core.gapic_v1.method.DEFAULT,
                metadata=None):
        """
        Forces a job to run now.

        When this method is called, Cloud Scheduler will dispatch the job, even
        if the job is already running.

        Example:
            >>> from google.cloud import scheduler_v1beta1
            >>>
            >>> client = scheduler_v1beta1.CloudSchedulerClient()
            >>>
            >>> name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')
            >>>
            >>> response = client.run_job(name)

        Args:
            name (str): Required.

                The job name. For example:
                ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.scheduler_v1beta1.types.Job` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'run_job' not in self._inner_api_calls:
            self._inner_api_calls[
                'run_job'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.run_job,
                    default_retry=self._method_configs['RunJob'].retry,
                    default_timeout=self._method_configs['RunJob'].timeout,
                    client_info=self._client_info,
                )

        request = cloudscheduler_pb2.RunJobRequest(name=name, )
        return self._inner_api_calls['run_job'](
            request, retry=retry, timeout=timeout, metadata=metadata)



# -*- coding: utf-8 -*-
#
# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Wrappers for protocol buffer enum types."""

import enum


class HttpMethod(enum.IntEnum):
    """
    The HTTP method used to execute the job.

    Attributes:
      HTTP_METHOD_UNSPECIFIED (int): HTTP method unspecified. Defaults to POST.
      POST (int): HTTP POST
      GET (int): HTTP GET
      HEAD (int): HTTP HEAD
      PUT (int): HTTP PUT
      DELETE (int): HTTP DELETE
      PATCH (int): HTTP PATCH
      OPTIONS (int): HTTP OPTIONS
    """
    HTTP_METHOD_UNSPECIFIED = 0
    POST = 1
    GET = 2
    HEAD = 3
    PUT = 4
    DELETE = 5
    PATCH = 6
    OPTIONS = 7


class Job(object):
    class State(enum.IntEnum):
        """
        State of the job.

        Attributes:
          STATE_UNSPECIFIED (int): Unspecified state.
          ENABLED (int): The job is executing normally.
          PAUSED (int): The job is paused by the user. It will not execute. A user can
          intentionally pause the job using ``PauseJobRequest``.
          DISABLED (int): The job is disabled by the system due to error. The user
          cannot directly set a job to be disabled.
          UPDATE_FAILED (int): The job state resulting from a failed ``CloudScheduler.UpdateJob``
          operation. To recover a job from this state, retry
          ``CloudScheduler.UpdateJob`` until a successful response is received.
        """
        STATE_UNSPECIFIED = 0
        ENABLED = 1
        PAUSED = 2
        DISABLED = 3
        UPDATE_FAILED = 4



# -*- coding: utf-8 -*-
#
# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Unit tests."""

import pytest

from google.cloud import scheduler_v1beta1
from google.cloud.scheduler_v1beta1.proto import cloudscheduler_pb2
from google.cloud.scheduler_v1beta1.proto import job_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self,
                    method,
                    request_serializer=None,
                    response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestCloudSchedulerClient(object):
    def test_list_jobs(self):
        # Setup Expected Response
        next_page_token = ''
        jobs_element = {}
        jobs = [jobs_element]
        expected_response = {'next_page_token': next_page_token, 'jobs': jobs}
        expected_response = cloudscheduler_pb2.ListJobsResponse(
            **expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        parent = client.location_path('[PROJECT]', '[LOCATION]')

        paged_list_response = client.list_jobs(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.jobs[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.ListJobsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_jobs_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        parent = client.location_path('[PROJECT]', '[LOCATION]')

        paged_list_response = client.list_jobs(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_get_job(self):
        # Setup Expected Response
        name_2 = 'name2-1052831874'
        description = 'description-1724546052'
        schedule = 'schedule-697920873'
        time_zone = 'timeZone36848094'
        expected_response = {
            'name': name_2,
            'description': description,
            'schedule': schedule,
            'time_zone': time_zone
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        response = client.get_job(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.GetJobRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        with pytest.raises(CustomException):
            client.get_job(name)

    def test_create_job(self):
        # Setup Expected Response
        name = 'name3373707'
        description = 'description-1724546052'
        schedule = 'schedule-697920873'
        time_zone = 'timeZone36848094'
        expected_response = {
            'name': name,
            'description': description,
            'schedule': schedule,
            'time_zone': time_zone
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        parent = client.location_path('[PROJECT]', '[LOCATION]')
        job = {}

        response = client.create_job(parent, job)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.CreateJobRequest(
            parent=parent, job=job)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        parent = client.location_path('[PROJECT]', '[LOCATION]')
        job = {}

        with pytest.raises(CustomException):
            client.create_job(parent, job)

    def test_update_job(self):
        # Setup Expected Response
        name = 'name3373707'
        description = 'description-1724546052'
        schedule = 'schedule-697920873'
        time_zone = 'timeZone36848094'
        expected_response = {
            'name': name,
            'description': description,
            'schedule': schedule,
            'time_zone': time_zone
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        job = {}

        response = client.update_job(job)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.UpdateJobRequest(job=job)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        job = {}

        with pytest.raises(CustomException):
            client.update_job(job)

    def test_delete_job(self):
        channel = ChannelStub()
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        client.delete_job(name)

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.DeleteJobRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        with pytest.raises(CustomException):
            client.delete_job(name)

    def test_pause_job(self):
        # Setup Expected Response
        name_2 = 'name2-1052831874'
        description = 'description-1724546052'
        schedule = 'schedule-697920873'
        time_zone = 'timeZone36848094'
        expected_response = {
            'name': name_2,
            'description': description,
            'schedule': schedule,
            'time_zone': time_zone
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        response = client.pause_job(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.PauseJobRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_pause_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        with pytest.raises(CustomException):
            client.pause_job(name)

    def test_resume_job(self):
        # Setup Expected Response
        name_2 = 'name2-1052831874'
        description = 'description-1724546052'
        schedule = 'schedule-697920873'
        time_zone = 'timeZone36848094'
        expected_response = {
            'name': name_2,
            'description': description,
            'schedule': schedule,
            'time_zone': time_zone
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        response = client.resume_job(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.ResumeJobRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_resume_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        with pytest.raises(CustomException):
            client.resume_job(name)

    def test_run_job(self):
        # Setup Expected Response
        name_2 = 'name2-1052831874'
        description = 'description-1724546052'
        schedule = 'schedule-697920873'
        time_zone = 'timeZone36848094'
        expected_response = {
            'name': name_2,
            'description': description,
            'schedule': schedule,
            'time_zone': time_zone
        }
        expected_response = job_pb2.Job(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup Request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        response = client.run_job(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = cloudscheduler_pb2.RunJobRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_run_job_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        client = scheduler_v1beta1.CloudSchedulerClient(channel=channel)

        # Setup request
        name = client.job_path('[PROJECT]', '[LOCATION]', '[JOB]')

        with pytest.raises(CustomException):
            client.run_job(name)
